==> haskell-http-download-0.1.0.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-download
version: 0.1.0.0
id: http-download-0.1.0.0-HiejYDocmTNJA2iXEF91nq
key: http-download-0.1.0.0-HiejYDocmTNJA2iXEF91nq
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Verified downloads with retries
category: Development
abi: 2d59af81343de12a4006dd7da43edf03
exposed: True
exposed-modules:
    Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules: Paths_http_download
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-download-0.1.0.0
hs-libraries: HShttp-download-0.1.0.0-HiejYDocmTNJA2iXEF91nq
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-6wGhn7vdA3B6uXWcLIr87M
    conduit-extra-1.3.4-K6FXFWghk929uw0H6vW1f
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    cryptonite-conduit-0.2.2-BCacdClaDrDurmhP9V6zT directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-client-0.6.4-5F3g2gtRkbJCEu8wzvrA41
    http-conduit-2.3.7.1-B08ieaTirROJ2iGsVG2V8n
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
haddock-interfaces: /usr/share/doc/haskell-http-download/html/http-download.haddock
haddock-html: /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.1.0.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-download
version: 0.1.0.0
id: http-download-0.1.0.0-7isFfj5OY1wIQMHkFhWBSH
key: http-download-0.1.0.0-7isFfj5OY1wIQMHkFhWBSH
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Verified downloads with retries
category: Development
abi: 4382a6ffe9bfa86749fda0eaa7b05e83
exposed: True
exposed-modules:
    Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules: Paths_http_download
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-download-0.1.0.0
hs-libraries: HShttp-download-0.1.0.0-7isFfj5OY1wIQMHkFhWBSH
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-1ExJakW9MWTDhowrClUKvK
    conduit-extra-1.3.4-H8AB5qQ1Jz7FmgvFl7Elz4
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    cryptonite-conduit-0.2.2-JxQVXmzqui5bnqk0M5A1u directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-client-0.6.4-5F3g2gtRkbJCEu8wzvrA41
    http-conduit-2.3.7.1-2DpmtvYM9nMAkERZ9tq04H
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
haddock-interfaces: /usr/share/doc/haskell-http-download/html/http-download.haddock
haddock-html: /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
